#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.2.0
visibility:           public
id:                   hslua-module-doclayout-1.2.0-7ajMTWMxdqg62ZTP3xIakK
key:                  hslua-module-doclayout-1.2.0-7ajMTWMxdqg62ZTP3xIakK
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  a2781ae6381dc5914cb84c720f38a762
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.2.0-7ajMTWMxdqg62ZTP3xIakK
depends:
    base-4.18.2.1 doclayout-0.5-D4TQyU8Ouyp8ieeDkMZYfw
    hslua-2.3.0-41qBgAeRFByAfkUM97kcus text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

